==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/theming/l10n/nl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laden voorbeeld...",
    "Admin" : "Beheer",
    "Saved" : "Opgeslagen",
    "a safe home for all your data" : "een veilige plek voor al je gegevens",
    "Name cannot be empty" : "Naam mag niet leeg zijn",
    "The given name is too long" : "De opgegeven naam is te lang",
    "The given web address is too long" : "Het opgegeven internetadres is te lang",
    "The given web address is not a valid URL" : "Het opgegeven internetadres is geen geldige URL",
    "The given legal notice address is too long" : "Het opgegeven adres voor de juridische melding is te lang",
    "The given legal notice address is not a valid URL" : "Het opgegeven adres voor de juridische melding geen geldige URL",
    "The given privacy policy address is too long" : "Het opgegeven adres met privacybeleid is te lang",
    "The given privacy policy address is not a valid URL" : "Het opgegeven adres met privacybeleid is geen geldige URL",
    "The given slogan is too long" : "De opgegeven slagzin is te lang",
    "The given color is invalid" : "De opgegeven kleur is ongeldig",
    "The file was uploaded" : "Het bestand werd geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize richtlijn in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE richtlijn die is opgegeven in het HTML formulier",
    "The file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Could not write file to disk" : "Kan bestand niet opslaan",
    "A PHP extension stopped the file upload" : "Een PHP extensie heeft de upload gestopt.",
    "No file uploaded" : "Geen bestand geüpload",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Je gebruikt al een aangepast thema. Theming app opties kunnen daardoor worden overschreven.",
    "Theming" : "Uiterlijk",
    "Appearance and accessibility" : "Weergave en toegankelijkheid",
    "Dark theme with high contrast mode" : "Donker thema met hoog contrast modus",
    "Enable dark high contrast mode" : "Donkere hoog contrast modus inschakelen",
    "Similar to the high contrast mode, but with dark colours." : "Vergelijkbaar met de hoog contrast modus, maar met donkere kleuren",
    "Dark theme" : "Donker thema",
    "Enable dark theme" : "Donker thema inschakelen",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Een donker thema om je ogen te laten rusten door het verminderen van de algehele lichtsterkte en helderheid.",
    "System default theme" : "Standaard systeemthema",
    "Enable the system default" : "Schakel het standaard systeemthema in",
    "Using the default system appearance." : "De standaard systeemweergave gebruiken",
    "Dyslexia font" : "Dyslexie-lettertype",
    "Enable dyslexia font" : "Dyslexie-lettertype inschakelen",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is een open source lettertype dat is ontwikkeld om de meest voorkomende leesfouten die worden veroorzaakt door dyslexie te voorkomen.",
    "High contrast mode" : "Hoog contrast modus",
    "Enable high contrast mode" : "Hoog contrast modus inschakelen",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Een thema met hoog contrast dat de navigatie vergemakkelijkt. De visuele kwaliteit vermindert, maar de duidelijkheid neemt toe.",
    "Light theme" : "Licht thema",
    "Enable the default light theme" : "Schakel het standaard lichte thema in",
    "The default light appearance." : "De standaard lichte weergave.",
    "Legal notice" : "Juridische bepalingen",
    "Privacy policy" : "Privacybeleid",
    "Adjust the Nextcloud theme" : "Nextcloud thema bijstellen",
    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
    "Background" : "Achtergrond",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universele toegang is heel belangrijk voor ons. We volgen webstandaarden en controleren dat alles ook zonder muis en met ondersteunende software zoals schermlezers bruikbaar is. We streven om de {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 op AA-niveau te volgen, en met het hoge contrast thema zelfs op AAA-niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Als je problemen tegenkomt, aarzel dan niet om deze te rapporteren op {issuetracker}onze issue tracker{linkend}. En als je betrokken wilt raken, word dan lid van {designteam}ons designteam{linkend}!",
    "Pick from Files" : "Kies uit Bestanden",
    "Plain background" : "Kale achtergrond",
    "Insert from {productName}" : "Invoegen vanuit {productName}",
    "Theme selection is enforced" : "Themaselectie is afgedwongen",
    "Open documentation" : "Documentatie openen",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Thematiseren maakt het mogelijk om uiterlijk en gevoel van je systeem en ondersteunde clients aan te passen. Dit wordt zichtbaar voor alle gebruikers.",
    "Name" : "Naam",
    "Reset to default" : "Herstellen naar standaard",
    "Web link" : "Weblink",
    "https://…" : "https://…",
    "Slogan" : "Slagzin",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nieuw logo",
    "Login image" : "Inlog afbeelding",
    "Upload new login background" : "Uploaden nieuwe inlog achtergrond",
    "Remove background image" : "Achtergrond beeld verwijderen",
    "Advanced options" : "Geavanceerde opties",
    "Legal notice link" : "Link naar juridische bepalingen",
    "Privacy policy link" : "Privacybeleid link",
    "Header logo" : "Top logo",
    "Upload new header logo" : "Upload een nieuwe top afbeelding",
    "Favicon" : "Favorietenpictogram",
    "Upload new favicon" : "Upload een nieuwe favorietenpictogram",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installeer de Imagemagick PHP extensie met ondersteuning voor SVG afbeeldingen om automatisch favicons te genereren op basis van het geuploade logo en kleur."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/theming/l10n/nl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "De opgegeven naam is te lang",
    "The given web address is too long" : "Het opgegeven internetadres is te lang",
    "The given web address is not a valid URL" : "Het opgegeven internetadres is geen geldige URL",
    "The given legal notice address is too long" : "Het opgegeven adres voor de juridische melding is te lang",
    "The given legal notice address is not a valid URL" : "Het opgegeven adres voor de juridische melding geen geldige URL",
    "The given privacy policy address is too long" : "Het opgegeven adres met privacybeleid is te lang",
    "The given privacy policy address is not a valid URL" : "Het opgegeven adres met privacybeleid is geen geldige URL",
    "The given slogan is too long" : "De opgegeven slagzin is te lang",
    "The given color is invalid" : "De opgegeven kleur is ongeldig",
    "Disable-user-theming should be true or false" : "Uitschakelen-gebruiker-thema's moet waar of onwaar zijn",
    "Saved" : "Opgeslagen",
    "The file was uploaded" : "Het bestand werd geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize richtlijn in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE richtlijn die is opgegeven in het HTML formulier",
    "The file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Could not write file to disk" : "Kan bestand niet opslaan",
    "A PHP extension stopped the file upload" : "Een PHP extensie heeft de upload gestopt.",
    "No file uploaded" : "Geen bestand geüpload",
    "Cleanup old theming cache" : "Verouderd thema cache opruimen",
    "Failed to delete folder: \"%1$s\", error: %2$s" : "Verwijderen van de map mislukt: \"%1$s\", foutmelding: %2$s",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Je gebruikt al een aangepast thema. Theming app opties kunnen daardoor worden overschreven.",
    "Theming" : "Uiterlijk",
    "Appearance and accessibility" : "Weergave en toegankelijkheid",
    "Dark theme with high contrast mode" : "Donker thema met hoog contrast modus",
    "Enable dark high contrast mode" : "Donkere hoog contrast modus inschakelen",
    "Similar to the high contrast mode, but with dark colours." : "Vergelijkbaar met de hoog contrast modus, maar met donkere kleuren",
    "Dark theme" : "Donker thema",
    "Enable dark theme" : "Donker thema inschakelen",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Een donker thema om je ogen te laten rusten door het verminderen van de algehele lichtsterkte en helderheid.",
    "System default theme" : "Standaard systeemthema",
    "Enable the system default" : "Schakel het standaard systeemthema in",
    "Using the default system appearance." : "De standaard systeemweergave gebruiken",
    "Dyslexia font" : "Dyslexie-lettertype",
    "Enable dyslexia font" : "Dyslexie-lettertype inschakelen",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is een open source lettertype dat is ontwikkeld om de meest voorkomende leesfouten die worden veroorzaakt door dyslexie te voorkomen.",
    "High contrast mode" : "Hoog contrast modus",
    "Enable high contrast mode" : "Hoog contrast modus inschakelen",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Een thema met hoog contrast dat de navigatie vergemakkelijkt. De visuele kwaliteit vermindert, maar de duidelijkheid neemt toe.",
    "Light theme" : "Licht thema",
    "Enable the default light theme" : "Schakel het standaard lichte thema in",
    "The default light appearance." : "De standaard lichte weergave.",
    "Legal notice" : "Juridische bepalingen",
    "Privacy policy" : "Privacybeleid",
    "Adjust the Nextcloud theme" : "Nextcloud thema bijstellen",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Thematiseren maakt het mogelijk om uiterlijk en gevoel van je systeem en ondersteunde clients aan te passen. Dit wordt zichtbaar voor alle gebruikers.",
    "Advanced options" : "Geavanceerde opties",
    "Name" : "Naam",
    "Web link" : "Weblink",
    "a safe home for all your data" : "een veilige plek voor al je gegevens",
    "Slogan" : "Slagzin",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nieuw logo",
    "Background and login image" : "Achtergrond en aanmeld afbeelding",
    "Legal notice link" : "Link naar juridische bepalingen",
    "Privacy policy link" : "Privacybeleid link",
    "Header logo" : "Top logo",
    "Upload new header logo" : "Upload een nieuwe top afbeelding",
    "Favicon" : "Favorietenpictogram",
    "Upload new favicon" : "Upload een nieuwe favorietenpictogram",
    "User settings" : "Instellingen gebruiker",
    "Disable user theming" : "Gebruiker thema's uitschakelen",
    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In sommige gevallen kunnen sneltoetsen interfereren met toegankelijkheidstools. Om de juiste focus op uw hulpmiddel mogelijk te maken, kunt u hier alle sneltoetsen uitschakelen. Dit zal ook alle beschikbare sneltoetsen in apps uitschakelen.",
    "Disable all keyboard shortcuts" : "Schakel alle sneltoetsen uit",
    "Background" : "Achtergrond",
    "Customization has been disabled by your administrator" : "Maatwerk is uitgeschakeld door uw beheerder",
    "Set a custom background" : "Stel persoonlijke achtergrond in",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universele toegang is heel belangrijk voor ons. We volgen webstandaarden en controleren dat alles ook zonder muis en met ondersteunende software zoals schermlezers bruikbaar is. We streven om de {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 op AA-niveau te volgen, en met het hoge contrast thema zelfs op AAA-niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Als je problemen tegenkomt, aarzel dan niet om deze te rapporteren op {issuetracker}onze issue tracker{linkend}. En als je betrokken wilt raken, word dan lid van {designteam}ons designteam{linkend}!",
    "Pick from Files" : "Kies uit Bestanden",
    "Default image" : "Standaard afbeelding",
    "Custom color" : "Kleur op maat",
    "Plain background" : "Kale achtergrond",
    "Insert from {productName}" : "Invoegen vanuit {productName}",
    "Theme selection is enforced" : "Themaselectie is afgedwongen",
    "Reset to default" : "Herstellen naar standaard",
    "Upload" : "Uploaden",
    "Remove background image" : "Achtergrond beeld verwijderen",
    "Loading preview…" : "Laden voorbeeld...",
    "Admin" : "Beheer",
    "Name cannot be empty" : "Naam mag niet leeg zijn",
    "Open documentation" : "Documentatie openen",
    "https://…" : "https://…",
    "Login image" : "Inlog afbeelding",
    "Upload new login background" : "Uploaden nieuwe inlog achtergrond",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installeer de Imagemagick PHP extensie met ondersteuning voor SVG afbeeldingen om automatisch favicons te genereren op basis van het geuploade logo en kleur.",
    "Error uploading the file" : "Fout bij uploaden van het bestand"
},
"nplurals=2; plural=(n != 1);");
